@@ -245,13 +245,13 @@ def mysql_proc(request):
             --port={port} --socket={socket} --log-error={logfile}
             --skip-syslog
         '''.format(
-            mysql_server=config.mysql.mysql_server,
-            datadir=config.mysql.datadir,
-            pidfile=config.mysql.pidfile,
-            port=config.mysql.port,
-            socket=config.mysql.socket,
-            logfile=config.mysql.logfile,
-        ),
+        mysql_server=config.mysql.mysql_server,
+        datadir=config.mysql.datadir,
+        pidfile=config.mysql.pidfile,
+        port=config.mysql.port,
+        socket=config.mysql.socket,
+        logfile=config.mysql.logfile,
+    ),
         host=config.mysql.host,
         port=config.mysql.port,
     )
@@ -274,8 +274,7 @@ def mysql_proc(request):
     return mysql_executor
 
 
-@pytest.fixture(scope='session')
-def mysqldb_session(request, mysql_proc):
+def mysqldb_fixture(request, mysql_proc):
     config = get_config(request)
 
     MySQLdb, config = try_import(
@@ -300,13 +299,5 @@ def mysqldb_session(request, mysql_proc):
     return mysql_conn
 
 
-@pytest.fixture
-def mysqldb(request, mysqldb_session):
-
-    def drop_database():
-        config = get_config(request)
-        mysqldb_session.query('DROP DATABASE IF EXISTS %s' % config.mysql.db)
-
-    request.addfinalizer(drop_database)
-
-    return mysqldb_session
+mysqldb_session = pytest.fixture(scope='session')(mysqldb_fixture)
+mysqldb = pytest.fixture(scope='function')(mysqldb_fixture)
